@@ -1,7 +1,9 @@
 import _ from 'lodash';
 import chrome from 'ui/chrome';
 
-export function filterParamsPhraseController($http, $scope) {
+export function filterParamsPhraseController($http, $scope, config) {
+  const shouldSuggestValues = this.shouldSuggestValues = config.get('filterEditor:suggestValues');
+
   this.compactUnion = _.flow(_.union, _.compact);
 
   this.getValueSuggestions = _.memoize(getValueSuggestions, getFieldQueryHash);
@@ -14,7 +16,7 @@ export function filterParamsPhraseController($http, $scope) {
   this.refreshValueSuggestions();
 
   function getValueSuggestions(field, query) {
-    if (!_.get(field, 'aggregatable') || field.type !== 'string') {
+    if (!shouldSuggestValues || !_.get(field, 'aggregatable') || field.type !== 'string') {
       return Promise.resolve([]);
     }
 
